API Documentation
=================

lightcurve\_fitting.bolometric module
-------------------------------------

.. automodule:: lightcurve_fitting.bolometric
   :members:
   :undoc-members:
   :show-inheritance:

lightcurve\_fitting.filters module
----------------------------------

.. automodule:: lightcurve_fitting.filters
   :members:
   :undoc-members:
   :show-inheritance:

lightcurve\_fitting.fitting module
----------------------------------

.. automodule:: lightcurve_fitting.fitting
   :members:
   :undoc-members:
   :show-inheritance:

lightcurve\_fitting.lightcurve module
-------------------------------------

.. automodule:: lightcurve_fitting.lightcurve
   :members:
   :undoc-members:
   :show-inheritance:

lightcurve\_fitting.models module
---------------------------------

.. automodule:: lightcurve_fitting.models
   :members:
   :undoc-members:
   :show-inheritance:

lightcurve\_fitting.speccal module
----------------------------------

.. automodule:: lightcurve_fitting.speccal
   :members:
   :undoc-members:
   :show-inheritance:
